@@ -16,10 +16,9 @@
 #include <unistd.h>
 #include <arpa/inet.h>
 #include <assert.h>
+#include <netdb.h>
 
-#include "missing/ancient_ruby.h"
-#include "nonblock.h"
-#include "my_fileno.h"
+#include "ancient_ruby.h"
 
 struct io_args {
 	VALUE io;
@@ -33,8 +32,18 @@ void init_kgio_wait(void);
 void init_kgio_read_write(void);
 void init_kgio_accept(void);
 void init_kgio_connect(void);
+void init_kgio_autopush(void);
+void init_kgio_poll(void);
+void init_kgio_tryopen(void);
+
+void kgio_autopush_accept(VALUE, VALUE);
+void kgio_autopush_recv(VALUE);
+void kgio_autopush_send(VALUE);
 
 VALUE kgio_call_wait_writable(VALUE io);
 VALUE kgio_call_wait_readable(VALUE io);
+#if defined(HAVE_RB_THREAD_BLOCKING_REGION) && defined(HAVE_POLL)
+#  define USE_KGIO_POLL
+#endif /* USE_KGIO_POLL */
 
 #endif /* KGIO_H */
